#include <Stepper.h>

// Number of steps per output rotation
const int stepsPerRevolution = 200;

// Create an instance of the Stepper library
Stepper myStepper(stepsPerRevolution, 26, 27, 28, 29);

// Button pin
const int buttonPin = 2;

// Button state variables
int buttonState = HIGH;
int previousButtonState = HIGH;

// Stepper mode variables
enum StepperMode {
  MODE_1,
  MODE_2
};

StepperMode currentMode = MODE_1;

// Control pin 6 timing variables
const unsigned long pin6OnTime = 43200000;   // Duration pin 6 is ON (in milliseconds)
const unsigned long pin6OffTime = 43200000; // Duration pin 6 is OFF (in milliseconds)
unsigned long pin6PreviousTime = 0;      // Previous time pin 6 state was changed

void setup() {
  // Set button pin mode to input
  pinMode(buttonPin, INPUT);

  // Set the speed at 60 rpm:
  myStepper.setSpeed(20);

  // Set pin 6 as output
  pinMode(6, OUTPUT);
}

void setStepperIdle() {
  digitalWrite(26, LOW);
  digitalWrite(27, LOW);
  digitalWrite(28, LOW);
  digitalWrite(29, LOW);
}

void loop() {
  // Read the current button state
  buttonState = digitalRead(buttonPin);

  // Check if the button state has changed
  if (buttonState != previousButtonState) {
    // If the button is pressed (LOW)
    if (buttonState == LOW) {
      // Switch between stepper modes
      if (currentMode == MODE_1) {
        currentMode = MODE_2;
      } else {
        currentMode = MODE_1;
      }
    }
    // Delay for debouncing
    delay(50);
  }

  // Store the current button state for the next iteration
  previousButtonState = buttonState;

  // Perform the appropriate stepper action based on the current mode
  switch (currentMode) {
    case MODE_1:
      myStepper.step(100);
      setStepperIdle();
      delay(10000);
      break;
    case MODE_2:
      myStepper.step(15);
      setStepperIdle();
      delay(1600);
      break;
  }

  // Check if it's time to change the state of pin 6
  unsigned long currentTime = millis();
  if (currentTime - pin6PreviousTime >= pin6OnTime + pin6OffTime) {
    // Reset the previous time
    pin6PreviousTime = currentTime;
  }

  // Check if pin 6 should be ON
  if (currentTime - pin6PreviousTime < pin6OnTime) {
    digitalWrite(6, HIGH);
  } else {
    digitalWrite(6, LOW);
  }
}
